@@ -42,4 +42,16 @@ var renderer = new DashRenderer({
         console.log("post_b:", response);
     }
 })
+'''
+
+code_start = '''# Write your code here!
+# You can use G, K and H as a TransferFunctions.
+# By default here you can use these libraries:
+#    numpy as (np)
+#    sympy as (sp)
+#    control as (ct)
+#    control2020 as (ct20)
+
+pid = ct20.design.pid_with_root_placing(G, po=5, ts=10)
+print(pid)
 '''
\ No newline at end of file
